@@ -13,7 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
 from nova import exception
 
 from compute_hyperv.nova import constants
@@ -32,14 +33,12 @@ class SerialConsoleHandlerTestCase(test_base.HyperVBaseTestCase):
     def setUp(self):
         super(SerialConsoleHandlerTestCase, self).setUp()
 
-        pathutils.PathUtils.return_value.mock_get_log_paths.return_value = [
-            mock.sentinel.log_path]
-
+        mock_get_vm_console_logs = (
+            pathutils.PathUtils.return_value.get_vm_console_log_paths)
+        mock_get_vm_console_logs.return_value = [mock.sentinel.log_path]
         self._consolehandler = serialconsolehandler.SerialConsoleHandler(
             mock.sentinel.instance_name)
-
         self._consolehandler._log_path = mock.sentinel.log_path
-        self._consolehandler._vmutils = mock.Mock()
 
     @mock.patch.object(serialconsolehandler.SerialConsoleHandler,
                        '_setup_handlers')
