@@ -14,7 +14,7 @@
 
 """A Hyper-V Cluster Nova Compute driver."""
 
-from hyperv.nova.cluster import driver
+from compute_hyperv.nova.cluster import driver
 
 # NOTE: nova changed the way it imports drivers. All drivers must belong
 # in the nova.virt namespace.
